package com.yiqi.core.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.core.domain.ClothAdjunct;

/**
 * 衣服附件Service接口
 *
 * @author xiaohei
 * @date 2023-08-20
 */
public interface IClothAdjunctService extends IService<ClothAdjunct> {
    /**
     * 查询衣服附件
     *
     * @param id 衣服附件主键
     * @return 衣服附件
     */
    public ClothAdjunct selectClothAdjunctById(Long id);

    /**
     * 查询衣服附件列表
     *
     * @param clothAdjunct 衣服附件
     * @return 衣服附件集合
     */
    public List<ClothAdjunct> selectClothAdjunctList(ClothAdjunct clothAdjunct);

    /**
     * 新增衣服附件
     *
     * @param clothAdjunct 衣服附件
     * @return 结果
     */
    public int insertClothAdjunct(ClothAdjunct clothAdjunct);

    /**
     * 修改衣服附件
     *
     * @param clothAdjunct 衣服附件
     * @return 结果
     */
    public int updateClothAdjunct(ClothAdjunct clothAdjunct);

    /**
     * 批量删除衣服附件
     *
     * @param ids 需要删除的衣服附件主键集合
     * @return 结果
     */
    public int deleteClothAdjunctByIds(Long[] ids);

    /**
     * 删除衣服附件信息
     *
     * @param id 衣服附件主键
     * @return 结果
     */
    public int deleteClothAdjunctById(Long id);


    /**
     * 修改衣服附件状态
     *
     * @param clothAdjunct 衣服附件
     * @return 结果
     */
    public int updateClothAdjunctStatus(ClothAdjunct clothAdjunct);

}
